psychopy_ext.ui.Control.__init__ — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.ui.Control.__init__

`Control.` `__init__`(exp_choices, title='Project', size=None)

  Initializes user control interface.

  Determines automatically whether to open a Graphic User Interface (GUI) or operate in a Command Line Interface (CLI) based on the number of arguments in `sys.argv`.

  Args: | exp_choices `Choices`
  Kwargs: | title (str, default: ‘Project’) Title of the GUI app window. size (tuple of two int, default: None) Size of a GUI app. If None, tries to fit the contents. However, if you have multiple pages in the Listbook, it will probably do a poor job.